# an example with simulated univariate data
# load univariate data
data("gauss_1D_sample")
# computes the optimal bandwith for the sample x_i with all parameters set to their default value
bw.L2PCO.diag(gauss_1D_sample)
# an example with simulated multivariate data
# load multivariate data
data("gauss_mD_sample")
# computes the optimal bandwith for the sample x_i with all parameters set to their default value
# generates a warning since the tolerance value is not reached
bw.L2PCO.diag(gauss_mD_sample)
# To avoid this warning, it is possible to increase the parameter nh
bw.L2PCO.diag(gauss_mD_sample, nh = 80)
Run the code above in your browser using DataLab